/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.oasisOpen.docs.wsrf.x2005.x01.wsrfInterop20Draft03Wsdl;

import org.apache.ws.resource.properties.ResourceProperty;
import org.apache.ws.resource.lifetime.ResourceTerminationListener;
import org.apache.ws.addressing.EndpointReference;
import org.apache.ws.addressing.XmlBeansEndpointReference;
import org.apache.axis.message.addressing.Constants;
import org.oasisOpen.docs.wsrf.x2005.x01.wsrfInterop20Draft03.*;
import org.xmlsoap.schemas.ws.x2004.x08.addressing.EndpointReferenceType;
import java.math.BigInteger;
import java.util.Calendar;

/**
 * A JobPort WS-Resource.
 * <p/>
 * NOTE: This class is generated but IS meant to be modified.
 */
public class JobPortResource
   extends AbstractJobPortResource
{
   private String                m_jobName;
   private String                m_jobId;
   private String                m_origUserName = "Johann Gutenberg";
   private EndpointReference     m_printerRef;
   private boolean m_isReady = false;
   private PrinterPortResource m_printerResource;


    /**
     * Adds a listener to be invoked when the resource has been terminated.
     *
     * @param listener
     */
    public void addTerminationListener(ResourceTerminationListener listener)
    {

    }

    /**
    * Creates a new {@link JobPortResource} object.
    *
    * @param jobEpr DOCUMENT_ME
     * @param jobId DOCUMENT_ME
     * @param jobName DOCUMENT_ME
     * @param printerResource DOCUMENT_ME
     * @param origUserName DOCUMENT_ME
     */
   public JobPortResource( EndpointReference jobEpr,
                           String jobId,
                           String jobName,
                           PrinterPortResource printerResource,
                           String origUserName )
   {
      super(  );
      m_jobName         = jobName;
      m_jobId           = jobId;
      if(origUserName != null && !origUserName.equals(""))
      {
        m_origUserName    = origUserName;
      }
      setEndpointReference( jobEpr );
      m_printerResource = printerResource;
      m_printerRef      = printerResource.getEndpointReference();
   }

   /**
    * Creates a new {@link JobPortResource} object.
    *
    * @param jobEpr DOCUMENT_ME
    * @param jobId DOCUMENT_ME
    * @param jobName DOCUMENT_ME
    * @param printerResource DOCUMENT_ME
    */
   public JobPortResource( EndpointReference     jobEpr,
                           String                jobId,
                           String                jobName,
                           PrinterPortResource   printerResource )
   {
      this( jobEpr, jobId, jobName, printerResource, null );
   }

    public PrinterPortResource getPrinterResource()
    {
        return m_printerResource;
    }

    /**
    * Initializes this resource's state (properties, etc.).
    */
   public void init(  )
   {
      super.init(  );

      ResourceProperty resourceProperty = m_propSet.get( JobPortPropertyQNames.JOB_NAME );
      JobNameDocument  jobNameDocument = JobNameDocument.Factory.newInstance(  );
      jobNameDocument.setJobName( m_jobName );
      resourceProperty.add( jobNameDocument );

      resourceProperty = m_propSet.get( JobPortPropertyQNames.JOB_ID );
      JobIdDocument jobIdDocument = JobIdDocument.Factory.newInstance(  );
      jobIdDocument.setJobId( new BigInteger( m_jobId ) );
      resourceProperty.add( jobIdDocument );

      resourceProperty = m_propSet.get( JobPortPropertyQNames.JOB_ORIGINATING_USER_NAME );
      JobOriginatingUserNameDocument jobOriginatingUserNameDocument =
         JobOriginatingUserNameDocument.Factory.newInstance(  );
      jobOriginatingUserNameDocument.setJobOriginatingUserName( m_origUserName );
      resourceProperty.add( jobOriginatingUserNameDocument );

      resourceProperty = m_propSet.get( JobPortPropertyQNames.JOB_PRINTER_REFERENCE );
      JobPrinterReferenceDocument jobPrinterReferenceDocument =
         JobPrinterReferenceDocument.Factory.newInstance(  );
      jobPrinterReferenceDocument.setJobPrinterReference( (EndpointReferenceType) ((XmlBeansEndpointReference)m_printerRef).getXmlObject( Constants.NS_URI_ADDRESSING_2004_08 ) );
      resourceProperty.add( jobPrinterReferenceDocument );

      resourceProperty = m_propSet.get( JobPortPropertyQNames.JOB_REFERENCE );
      JobReferenceDocument jobReferenceDocument = JobReferenceDocument.Factory.newInstance(  );
      jobReferenceDocument.setJobReference( (EndpointReferenceType) ((XmlBeansEndpointReference)getEndpointReference()).getXmlObject( Constants.NS_URI_ADDRESSING_2004_08 ) );
      resourceProperty.add( jobReferenceDocument );

      resourceProperty = m_propSet.get( JobPortPropertyQNames.JOB_STATE );
      JobStateDocument jobStateDocument = JobStateDocument.Factory.newInstance(  );
      jobStateDocument.setJobState( JobStateType.PENDING );
      resourceProperty.add( jobStateDocument );

      Calendar currentTime = getCurrentTime();
      Calendar termTime = Calendar.getInstance(  );
      termTime.set( currentTime.get( Calendar.YEAR ),
                    currentTime.get( Calendar.MONTH ),
                    currentTime.get( Calendar.DATE ) + 2 );
      setTerminationTime( termTime );
   }

    public boolean isQueued() {
        return m_isReady;
    }

    public void enqueue()
    {
        m_isReady = true;
        m_printerResource.addJobToQueue(this);
    }

}