/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.addressing;

import javax.xml.namespace.QName;

/**
 * Interface for EndpointReferences
 *
 * @author Sal Campana
 */
public interface EndpointReference
{
   /**
    * Returns the Address from the EPR as a String.
    *
    * @return Address
    */
   String getAddress(  );

   /**
    * Returns the PortName associated with the Service in the EPR as a String
    *
    * @return Service's Port Name
    */
   String getPortName(  );

   /**
    * Returns the PortType QName
    *
    * @return PortType QName
    */
   QName getPortType(  );

   /**
    * Returns the ReferenceParameters Object.
    *
    * @return Object[] The ReferenceParameters
    */
   Object[] getReferenceParameters(  );

   /**
    * Returns the ReferenceProperties Object.
    *
    * @return Object[] The ReferenceProperties
    */
   Object[] getReferenceProperties(  );

   /**
    * Service QName
    *
    * @return Service QName
    */
   QName getServiceName(  );
}