/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource;

import org.apache.ws.addressing.EndpointReference;
import org.apache.ws.resource.lifetime.ResourceTerminationListener;

/**
 * A marker interface for a resource. All resource objects must implement this interface.
 */
public interface Resource
{
   /**
    * Sets the EndpointReference associated with this Resource.
    *
    * @param epr  The EndpointReference for the Resource.
    */
   void setEndpointReference( EndpointReference epr );

   /**
    * Returns the EndpointReference associated with this Resource.
    *
    * @return The Resource's EndpointReference
    */
   EndpointReference getEndpointReference(  );

   /**
    * @param id
    *
    * @throws IllegalArgumentException if the specified ID is not the of the correct type for this resource
    * @throws IllegalStateException    if this resource's ID has already been set
    */
   void setID( Object id );

   /**
    * Returns the unique id of the resource. In most cases, this value should match value returned by {@link
    * ResourceKey#getValue}.
    *
    * @return the id of the resource.
    */
   Object getID(  );

   /**
    * Adds a listener to be invoked when the resource has been terminated.
    *
    * @param listener
    */
   void addTerminationListener( ResourceTerminationListener listener );

   /**
    * Called by the resource home to indicate to a resource that the resource is
    * being taken out of service.
    */
   void destroy(  );

   /**
    * Called by the resource home to indicate to a resource that the resource is
    * being placed into service. A resource can use this method to initialize
    * its properties or any other state.
    */
   void init(  );
}