/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.handler;

import org.apache.commons.lang.StringUtils;
import org.apache.ws.resource.ResourceContext;
import javax.xml.namespace.QName;
import java.util.HashMap;
import java.util.Map;

/**
 * LOG-DONE
 * @author Sal Campana
 */
public class ServiceSoapMethodNameMap
   extends AbstractSoapMethodNameMap
{
   private Map m_RequestQnameToMethodNameMap;

   /**
    * Creates a new {@link ServiceSoapMethodNameMap} object.
    *
    * @param context             DOCUMENT_ME
    */
   public ServiceSoapMethodNameMap( ResourceContext context )
   {
      m_RequestQnameToMethodNameMap = new HashMap(  );
      setParent( new DefaultMethodMap( new WsddSoapMethodNameMap( context ) ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @param request DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public String getDefaultMethodName( QName request )
   {
      String methodName = (String) m_RequestQnameToMethodNameMap.get( request );
      if ( methodName == null )
      {
         methodName = StringUtils.uncapitalize( request.getLocalPart(  ) );
      }

      return methodName;
   }

   /**
    * Adds a mapping for a SOAP Message to Java Method name
    *
    * @param soapMsgQname
    * @param javaMethodName
    */
   public void addMapping( QName  soapMsgQname,
                           String javaMethodName )
   {
      m_RequestQnameToMethodNameMap.put( soapMsgQname, javaMethodName );
   }

   /**
    * Returns a Default name for a method based on a request's WS-Addressing Action Header.
    *
    * @param action String representation of WS-Addressing Action Header Value
    * @return The name of the operation OR null if there is no Action registered.
    */
   public String lookupMethodNameFromAction( String action )
   {
      String methodName = (String) m_RequestQnameToMethodNameMap.get( action );
      return methodName;
   }

   /**
    * DOCUMENT_ME
    *
    * @param soapMsgQname DOCUMENT_ME
    */
   public void removeMapping( QName soapMsgQname )
   {
      m_RequestQnameToMethodNameMap.remove( soapMsgQname );
   }
}