/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.properties;

import javax.xml.namespace.QName;

/**
 * @author Ian P. Springer
 */
public interface ResourcePropertySetMetaData
{
   /**
    * Returns the element name of the entire resource properties document.
    *
    * @return the element name of the entire resource properties document
    */
   QName getName(  );

   /**
    * Indicates if the resource property set allows adding of new arbitrary resource property elements.
    *
    * @return true if adding new resource property elements is allowed. False otherwise. Please note that
    *         <code>isOpenContent</code> might return <code>true</code>, but only certain subset of resource properties
    *         will be allowed to be added.
    */
   boolean isOpenContent(  );

   /**
    * Returns the metadata associated with the resource property with the specified name.
    *
    * @param name the name of a resource property
    *
    * @return the metadata associated with the resource property with the specified name
    */
   ResourcePropertyMetaData getPropertyMetaData( QName name );

   /**
    * Returns the metadata associated with all of the resource properties in this set.
    *
    * @return the metadata associated with all of the resource properties in this set
    */
   ResourcePropertyMetaData[] getPropertyMetaDatas(  );

   /**
    * Creates a resource property set of the type defined by this metadata.
    */
   ResourcePropertySet create(  );
}