/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.tool;

import javax.xml.namespace.QName;

/**
 * Contains the info needed to generate Java artifacts for a particular portType.
 *
 * @author Ian Springer (ian DOT springer AT hp DOT com)
 */
public abstract class PortType2JavaInfo
{
   /**
    * Returns the name of the portType that this object corresponds to.
    *
    * @return the name of the portType that this object corresponds to
    */
   public abstract QName getName(  );

   /**
    * Returns the name of a file containing text to be inserted into the body of the abstract resource's init() method.
    *
    * @return the name of a file containing text to be inserted into the body of the abstract resource's init() method
    */
   public String getAbstractResourceInitMethodIncludeLocation(  )
   {
      return null;
   }

   /**
    * Returns the name of a file containing text to be inserted into the body of the concrete resource's init() method.
    *
    * @return the name of a file containing text to be inserted into the body of the concrete resource's init() method
    */
   public String getResourceInitMethodIncludeLocation(  )
   {
      return null;
   }

   /**
    * Returns the name of an interface that the generated resource should implement,
    * or null if no interface should be implemented.
    *
    * @return the name of an interface that the generated resource should implement,
    *         or null if no interface should be implemented
    */
   public String getResourceInterfaceName(  )
   {
      return null;
   }

   /**
    * Returns the name of a Velocity template file that should be parsed and
    * included in the body of the generated resource class, or null if no
    * template should be parsed and included.
    *
    * @return the name of a Velocity template file that should be parsed and
    *         included in the body of the generated resource class, or null if no
    *         template should be parsed and included
    */
   public String getResourceTemplateFileName(  )
   {
      return null;
   }

   /**
    * Returns the name of an interface that the generated service should implement,
    * or null if no interface should be implemented.
    *
    * @return the name of an interface that the generated service should implement,
    *         or null if no interface should be implemented
    */
   public String getServiceInterfaceName(  )
   {
      return null;
   }

   /**
    * Returns the name of a Velocity template file that should be parsed and
    * included in the body of the generated service class, or null if no
    * template should be parsed and included.
    *
    * @return the name of a Velocity template file that should be parsed and
    *         included in the body of the generated service class, or null if no
    *         template should be parsed and included
    */
   public String getServiceTemplateFileName(  )
   {
      return null;
   }
}